Learn R Programming

pgnorm (version 2.0.1)

datasetpgnmp1: Dataset 1 of the Monty Python method

Description

The dataset contains tail algorithm constants for sampling from the tail of the \(p\)-generalized normal distribution in context of a simulation of the \(p\)-generalized normal distribution with the Monty Python method.

Usage

data(datasetpgnmp1)

Arguments

Examples

Run this code
data(datasetpgnmp1)

Run the code above in your browser using DataLab