Learn R Programming

pgnorm (version 2.0.1)

rpgnorm_montypython: A random number generator for the \(p\)-generalized normal distribution

Description

The function simulates the univariate, central, \(p\)-generalized normal distribution by using the Monty Python method.

Usage

rpgnorm_montypython(n,p)

Value

An \(n\)-dimensional, real vector.

Arguments

n

The natural number of random variables to be simulated.

p

A positive number expressing the form parameter of the distribution. The default is 2. In case of the Monty Python method, p can be chosen from \((1, \infty) \cup \{ 0.25, 0.45, 0.5, 0.6, 0.75 \} \).

Author

Steve Kalke

References

S. Kalke and W.-D. Richter (2013)."Simulation of the p-generalized Gaussian distribution." Journal of Statistical Computation and Simulation. Volume 83. Issue 4.

Examples

Run this code
y<-rpgnorm_montypython(10000,3)

Run the code above in your browser using DataLab