datasetpgnmp1: Dataset 1 of the Monty Python method
Description
The dataset contains tail algorithm constants for sampling from the tail of the \(p\)-generalized normal distribution in context of a simulation of the \(p\)-generalized normal distribution with the Monty Python method.