The pgnorm-package includes routines to evaluate (cdf,pdf) and simulate the univariate \(p\)-generalized normal distribution with form parameter \(p\), expectation \(mean\) and standard deviation \(\sigma\). The pdf of this distribution is given by $$f(x,p,mean,\sigma)=(\sigma_p/ \sigma) \, C_p \, \exp \left( - \left( \frac{\sigma_p}{\sigma } \right)^p \frac{\left| x-mean \right|^p}{p} \right) ,$$ where \(C_p=p^{1-1/p}/2/\Gamma(1/p)\) and \(\sigma_p^2=p^{2/p} \, \Gamma(3/p)/\Gamma(1/p)\), which becomes $$f(x,p,mean,\sigma)=C_p \, \exp \left( - \frac{\left| x \right|^p}{p} \right),$$ if \(\sigma=\sigma_p\) and \(mean=0\). The random number generation can be realized with one of five different simulation methods including the \(p\)-generalized polar method, the \(p\)-generalized rejecting polar method, the Monty Python method, the Ziggurat method and the method of Nardon and Pianca. Additionally to the simulation of the p-generalized normal distribution, the related \(p\)-generalized uniform distribution on the \(p\)-generalized unit circle and the corresponding angular distribution can be simulated by using the functions "rpgunif" and "rpgangular", respectively.
Steve Kalke <steve.kalke@googlemail.com>
| Package: | pgnorm |
| Type: | Package |
| Version: | 2.0 |
| Date: | 2015-11-23 |
| License: | GPL (>= 2) |
| LazyLoad: | yes |
S. Kalke and W.-D. Richter (2013)."Simulation of the p-generalized Gaussian distribution." Journal of Statistical Computation and Simulation. Volume 83. Issue 4.