The function simulates the univariate \(p\)-generalized normal distribution by using one of the following methods: the \(p\)-generalized polar method (pgenpolar), the \(p\)-generalized rejecting polar method (pgenpolarrej), the Monty Python method (montypython), the Ziggurat method (ziggurat) and the method of Nardon and Pianca (nardonpianca).
rpgnorm(n, p, mean, sigma, method)An \(n\)-dimensional, real vector.
The natural number of random variables to be simulated.
A positive number expressing the form parameter of the distribution. The default is 2. In case of the Monty Python method and the Ziggurat method, p can be chosen from \((1, \infty) \cup \{ 0.25, 0.45, 0.5, 0.6, 0.75 \} \).
A real number expressing the expectation of the distribution. The default is 0.
A positive number expressing the standard deviation of the distribution. The default is \(\sigma_p=p^{1/p} \, \sqrt{\Gamma(3/p)/ \Gamma(1/p)}\), the natural standard deviation of the \(p\)-generalized normal distribution.
A string expressing the method to be used for the simulation ("pgenpolar", "pgenpolarrej", "montypython", "ziggurat" or "nardonpianca"). The default is "nardonpianca".
Steve Kalke
S. Kalke and W.-D. Richter (2013)."Simulation of the p-generalized Gaussian distribution." Journal of Statistical Computation and Simulation. Volume 83. Issue 4.
y<-rpgnorm(10000,3,method="pgenpolar")Run the code above in your browser using DataLab