rpgnorm_nardonpianca: A random number generator for the \(p\)-generalized normal distribution
Description
The function simulates the univariate, central, \(p\)-generalized normal distribution by using the method of Nardon and Pianca.
Usage
rpgnorm_nardonpianca(n,p)
Value
An \(n\)-dimensional, real vector.
Arguments
n
The natural number of random variables to be simulated.
p
A positive number expressing the form parameter of the distribution. The default is 2.
Author
Steve Kalke
References
S. Kalke and W.-D. Richter (2013)."Simulation of the p-generalized Gaussian distribution." Journal of Statistical Computation and Simulation. Volume 83. Issue 4.