rpgunif: A random number generator for the \(p\)-generalized uniform distribution
Description
The function simulates the bivariate, \(p\)-generalized uniform distribution on the \(p\)-generalized unit circle.
Usage
rpgunif(n,p)
Value
A real \(n \times 2\) matrix.
Arguments
n
The natural number of random vectors to be simulated.
p
A positive number expressing the form parameter of the distribution. The default is 2.
Author
Steve Kalke
References
S. Kalke and W.-D. Richter (2013)."Simulation of the p-generalized Gaussian distribution." Journal of Statistical Computation and Simulation. Volume 83. Issue 4.